@@ -13,25 +13,22 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import print_function, absolute_import
-
 from ripe.atlas.cousteau import Measurement
 from ripe.atlas.cousteau.exceptions import APIResponseError
 
 from ..exceptions import RipeAtlasToolsException
 from ..renderers import Renderer
-from ..streaming import Stream, CaptureLimitExceeded
+from ..streaming import Stream
 from .base import Command as BaseCommand
-from ..settings import conf
+from ..helpers.validators import ArgumentType
 
 
 class Command(BaseCommand):
 
     NAME = "stream"
 
-    DESCRIPTION = (
-        "Output the results of a measurement as they become available"
-    )
+    DESCRIPTION = "Output the results of a public measurement as they become available"
+    EXTRA_DESCRIPTION = "Streaming of non-public measurements is not supported."
     URLS = {
         "detail": "/api/v2/measurements/{0}.json",
     }
@@ -39,52 +36,46 @@ class Command(BaseCommand):
     def add_arguments(self):
         self.parser.add_argument(
             "measurement_id",
-            type=int,
-            help="The measurement id you want streamed"
-        )
-        self.parser.add_argument(
-            "--auth",
-            type=str,
-            choices=conf["authorisation"]["fetch_aliases"].keys(),
-            default=conf["authorisation"]["fetch"],
-            help="The API key alias you want to use to fetch the measurement. "
-                 "To configure an API key alias, use "
-                 "ripe-atlas configure --set authorisation.fetch_aliases."
-                 "ALIAS_NAME=YOUR_KEY"
-
+            type=ArgumentType.msm_id_or_name(),
+            help="The measurement id or alias you want streamed",
         )
         self.parser.add_argument(
             "--limit",
             type=int,
-            help="The maximum number of results you want to stream"
+            help="The maximum number of results you want to stream",
         )
         self.parser.add_argument(
             "--renderer",
             choices=Renderer.get_available(),
             help="The renderer you want to use. If this isn't defined, an "
-                 "appropriate renderer will be selected."
+            "appropriate renderer will be selected.",
+        )
+        self.parser.add_argument(
+            "--timeout",
+            type=float,
+            help="Stop streaming after this number of seconds",
         )
 
-    def _get_request_auth(self):
-        if self.arguments.auth:
-            return conf["authorisation"]["fetch_aliases"][self.arguments.auth]
-        else:
-            return conf["authorisation"]["fetch"]
+        Renderer.add_arguments_for_available_renderers(self.parser)
 
     def run(self):
 
         try:
             measurement = Measurement(
-                id=self.arguments.measurement_id, user_agent=self.user_agent,
-                key=self._get_request_auth)
+                id=self.arguments.measurement_id,
+                user_agent=self.user_agent,
+            )
         except APIResponseError as e:
             raise RipeAtlasToolsException(e.args[0])
 
-        try:
-            Stream(capture_limit=self.arguments.limit).stream(
-                self.arguments.renderer,
-                measurement.type.lower(),
-                self.arguments.measurement_id
-            )
-        except (KeyboardInterrupt, CaptureLimitExceeded):
-            self.ok("Disconnecting from the stream")
+        self.ok("Connecting to stream...")
+        stream = Stream(
+            self.arguments.measurement_id,
+            capture_limit=self.arguments.limit,
+            timeout=self.arguments.timeout,
+        )
+        renderer = Renderer.get_renderer(
+            name=self.arguments.renderer, kind=measurement.type.lower()
+        )(arguments=self.arguments)
+        renderer.render(stream)
+        self.ok("Disconnected from stream")
